NameServerConfig

Struct NameServerConfig 

#[non_exhaustive]
pub struct NameServerConfig { pub ip: IpAddr, pub trust_negative_responses: bool, pub connections: Vec<ConnectionConfig>, }
Configuration for the NameServer

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
ip: IpAddr

The address which the DNS NameServer is registered at.

trust_negative_responses: bool

Whether to trust NXDOMAIN responses from upstream nameservers.

When this is true, and an empty NXDOMAIN response with an empty answers set is received, the query will not be retried against other configured name servers.

(On a response with any other error response code, the query will still be retried regardless of this configuration setting.)

Defaults to true.

connections: Vec<ConnectionConfig>

Connection protocols configured for this server.

Implementations

Source

impl NameServerConfig

pub fn udp_and_tcp(ip: IpAddr) -> Self

Constructs a nameserver configuration with a UDP and TCP connections

pub fn udp(ip: IpAddr) -> Self

Constructs a nameserver configuration with a single UDP connection

pub fn tcp(ip: IpAddr) -> Self

Constructs a nameserver configuration with a single TCP connection

pub fn new( ip: IpAddr, trust_negative_responses: bool, connections: Vec<ConnectionConfig>, ) -> Self

Create a new NameServerConfig from its constituent parts.